#File working with Vacancies Data for Piper_Lewis, June, 2022
#JPART Paper: "Vacancies and Federal AGency Performance"
#Date: June 3, 2022
#Descrption: This file includes the commands used to create the figures in Piper and Lewis 2022
#Data: jpart_self_perf_060222.xlsx


#First, I'll start with adding some useful packages.
#This first command removes all data in short term memory.
rm(list=ls())

#This command sets the working directory.

setwd("C:/Users/lewisde/Documents/R")

#Adding package for adding and joining datasets
install.packages("tidyverse")
library(tidyverse)
library(readxl)

#This package allows me to read in STATA files.
library (haven)
#This package allows the calculation of marginal effects
install.packages("margins")
library(margins)

#Now installing ggplot
install.packages("ggplot2")
install.packages("colorspace")
library(colorspace)
library(ggplot2)

library(ggpubr)

#This package will let me export regression tables.
library(stargazer)

#This package will let me do easy tests of means
install.packages("ggpubr")


##

##Figure 1: Agency_perf by Skills
library("readxl")
library(ggrepel)
library(ggpubr)
library(ggplot2)

library(readxl)
aperf <- read_excel("C:/Users/lewisde/Dropbox/Vacancies and Performance/JPART/Data/jpart_self_perf_060222.xlsx")

#Now scatter plot with line with error bars in ggplot. Plus adds new things. aes is x and y variables.
#method can be different kinds of models.

a<-ggplot(aperf, aes(x= skills_mean_20, y=agency_perf)) + 
  geom_text (aes(label=bureau_acr), size=2.5, position = position_jitter(0.15), check_overlap = T) +
  geom_smooth(method=lm, color='black')+
  theme(axis.title.y = element_blank())+
  xlab("2020 Workforce Skill Rating")+
  scale_x_continuous(limits = c(-2.5, 2.5))+
  scale_y_continuous(limits=c(1,5))

b<-ggplot(aperf, aes(x=beptw, y=agency_perf)) + 
  geom_text (aes(label=bureau_acr), size=2.5, position = position_jitter(0.15), check_overlap = T) +
  geom_smooth(method=lm, color='black')+
  theme(axis.title.y = element_blank())+
  xlab("2020 Pandemic Performance Score")+
  scale_x_continuous(limits=c(70,100)) +
  scale_y_continuous(limits=c(1,5))

figure1 <- ggarrange(a, b,
                     
                     ncol = 2, nrow = 1, align = "h")

annotate_figure(figure1, lef =text_grob ("Average Performance Rating", rot=90))

##Figure 2: Plots of Estimated Effects from Table 1 Estimates
library(margins)
library(readxl)
aperf <- read_excel("C:/Users/lewisde/Dropbox/Vacancies and Performance/avg_self_perf_031222.xlsx")
aperf$mvac<-(aperf$Total_Vacant_Days+1)/30

m<-lm(agency_perf~mvac, data=aperf, directPAS==1)

n<- lm(agency_perf~mvac+turnpas+eop+offsec+Bureau+indcom+depprior+bprior, data=aperf, directPAS==1)

o<- lm(agency_perf~mvac+turnpas+eop+offsec+Bureau+indcom+skills_mean_2014, data=aperf, directPAS==1)

par (mfrow=c(1,3))

cplot(m, cex.lab= 1.5, cex.axis=1.5, x="mvac", what = c("prediction"), ylim=c(2.5,5), ylab="Predicted Performance Rating", xlab="")
cplot(n, cex.lab= 1.5, cex.axis=1.5, x="mvac", what = c("prediction"), ylim=c(2.5,5), ylab="", xlab="Months Vacant")
cplot(o, cex.lab= 1.5, cex.axis=1.5, x="mvac", what = c("prediction"), ylim=c(2.5,5), ylab="", xlab="")

#Figure 3: Plots of Estimated Effects from Table 2 Estimates

m<-lm(invest_now~mvac+turnpas+eop+offsec+Bureau+indcom+depprior+bprior, data=aperf, directPAS==1)

n<- lm(fevs_agency~mvac+turnpas+eop+offsec+Bureau+indcom+depprior+bprior, data=aperf, directPAS==1)

o<- lm(sense_urgency~mvac+turnpas+eop+offsec+Bureau+indcom+depprior+bprior, data=aperf, directPAS==1)

p<- lm(sup_misn_app~mvac+turnpas+eop+offsec+Bureau+indcom+depprior+bprior, data=aperf, directPAS==1)

q<- lm(sup_misn_wh~mvac+turnpas+eop+offsec+Bureau+indcom+depprior+bprior, data=aperf, directPAS==1)

r<- lm(sup_misn_comm~mvac+turnpas+eop+offsec+Bureau+indcom+depprior+bprior, data=aperf, directPAS==1)


par (mfrow=c(1,3))


cplot(m, main="Investing Now for Future Success", cex.lab= 1.5, cex.axis=1.5, x="mvac", what = c("prediction"), ylim=c(1,5), ylab="Averge Agreement", xlab="")
cplot(n, main="Agency Morale", cex.lab= 1.5, cex.axis=1.5, x="mvac", what = c("prediction"), ylim=c(1,5), ylab="Average Satisfaction", xlab="Months Vacant")
cplot(o, main="Agency Has Sense of Urgency", cex.lab= 1.5, cex.axis=1.5, x="mvac", what = c("prediction"), ylim=c(1,5), ylab="Average Agreement", xlab="")


#Figure 4: Plots of Estimated Effects from Table 2 Estimates
par (mfrow=c(1,3))
cplot(p, main="Appointee Effort", cex.lab= 1.5, cex.axis=1.5, x="mvac", what = c("prediction"), ylim=c(1,5), ylab="Effort Supporting Mission", xlab="")
cplot(q, main="WH Effort", cex.lab= 1.5, cex.axis=1.5, x="mvac", what = c("prediction"), ylim=c(1,5), ylab="", xlab="Months Vacant")
cplot(r, main="Committee Effort", cex.lab= 1.5, cex.axis=1.5, x="mvac", what = c("prediction"), ylim=c(1,5), ylab="", xlab="")


